BugseeVideoQuality enum
Values
- defaultQuality → const BugseeVideoQuality
-
Default video quality suitable for most scenarios. The resulting video is encoded into container with resolution of up to 640x640
- medium → const BugseeVideoQuality
-
Suitable for visual contents with medium original resolution (up to 2K pixels). The resulting video is encoded into container with resolution of up to 960x960
- high → const BugseeVideoQuality
-
Suitable for visual contents with high original resolution (more than 2K pixels). The resulting video is encoded into container with resolution of up to 1280x1280
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BugseeVideoQuality> - A constant List of the values in this enum, in order of their declaration.